@@ -14,7 +14,7 @@ from anki.facts import factsTable, fieldsTable, Fact
 from anki.utils import fmtTimeSpan, parseTags, findTag, addTags, deleteTags, \
      stripHTML, ids2str
 from ankiqt.ui.utils import saveGeom, restoreGeom, saveSplitter, restoreSplitter
-from ankiqt.ui.utils import saveHeader, restoreHeader
+from ankiqt.ui.utils import saveHeader, restoreHeader, saveState, restoreState
 from anki.errors import *
 from anki.db import *
 from anki.stats import CardStats
@@ -32,6 +32,7 @@ CARD_INTERVAL = 8
 CARD_EASE = 9
 CARD_NO = 10
 CARD_PRIORITY = 11
+CARD_TAGS = 12
 
 # Deck editor
 ##########################################################################
@@ -170,8 +171,9 @@ where cards.factId = facts.id """
     def updateCard(self, index):
         try:
             self.cards[index.row()] = self.deck.s.first("""
-    select id, question, answer, due, reps, factId, created, modified,
-    interval, noCount, factor, priority from cards where id = :id""",
+select id, question, answer, due, reps, factId, created, modified,
+interval, factor, noCount, priority, (select tags from facts where
+facts.id = cards.factId) from cards where id = :id""",
                                                         id=self.cards[index.row()][0])
             self.emit(SIGNAL("dataChanged(QModelIndex,QModelIndex)"),
                       index, self.index(index.row(), 1))
@@ -265,7 +267,7 @@ where cards.factId = facts.id """
         return "%0.2f" % self.cards[index.row()][CARD_EASE]
 
     def noColumn(self, index):
-        return "%d" % self.cards[index.row()][CARD_EASE]
+        return "%d" % self.cards[index.row()][CARD_NO]
 
 class StatusDelegate(QItemDelegate):
 
@@ -277,7 +279,7 @@ class StatusDelegate(QItemDelegate):
         if len(self.model.cards[index.row()]) == 1:
             self.model.updateCard(index)
         row = self.model.cards[index.row()]
-        if row[CARD_PRIORITY] in (-3, 0):
+        if row[CARD_PRIORITY] == -3:
             # custom render
             if index.row() % 2 == 0:
                 brush = QBrush(QColor("#ffffcc"))
@@ -286,6 +288,23 @@ class StatusDelegate(QItemDelegate):
             painter.save()
             painter.fillRect(option.rect, brush)
             painter.restore()
+        if row[CARD_PRIORITY] == 0:
+            # custom render
+            if index.row() % 2 == 0:
+                brush = QBrush(QColor("#ffcccc"))
+            else:
+                brush = QBrush(QColor("#ffaaaa"))
+            painter.save()
+            painter.fillRect(option.rect, brush)
+            painter.restore()
+        elif "Marked" in row[CARD_TAGS]:
+            if index.row() % 2 == 0:
+                brush = QBrush(QColor("#ccccff"))
+            else:
+                brush = QBrush(QColor("#aaaaff"))
+            painter.save()
+            painter.fillRect(option.rect, brush)
+            painter.restore()
         return QItemDelegate.paint(self, painter, option, index)
 
 class EditDeck(QMainWindow):
@@ -305,8 +324,14 @@ class EditDeck(QMainWindow):
         self.lastFilter = ""
         self.dialog = ankiqt.forms.cardlist.Ui_MainWindow()
         self.dialog.setupUi(self)
+        self.setUnifiedTitleAndToolBarOnMac(True)
         restoreGeom(self, "editor")
+        restoreState(self, "editor")
         restoreSplitter(self.dialog.splitter, "editor")
+        # toolbar
+        self.dialog.toolBar.setIconSize(QSize(self.config['iconSize'],
+                                              self.config['iconSize']))
+        self.dialog.toolBar.toggleViewAction().setText(_("Toggle Toolbar"))
         # flush all changes before we load
         self.deck.s.flush()
         self.model = DeckModel(self.parent, self.parent.deck)
@@ -621,6 +646,7 @@ class EditDeck(QMainWindow):
 
     def setupMenus(self):
         # actions
+        self.connect(self.dialog.actionAddItems, SIGNAL("triggered()"), self.parent.onAddCard)
         self.connect(self.dialog.actionDelete, SIGNAL("triggered()"), self.deleteCards)
         self.connect(self.dialog.actionAddTag, SIGNAL("triggered()"), self.addTags)
         self.connect(self.dialog.actionDeleteTag, SIGNAL("triggered()"), self.deleteTags)
@@ -628,8 +654,8 @@ class EditDeck(QMainWindow):
         self.connect(self.dialog.actionCram, SIGNAL("triggered()"), self.cram)
         self.connect(self.dialog.actionAddCards, SIGNAL("triggered()"), self.addCards)
         self.connect(self.dialog.actionChangeModel, SIGNAL("triggered()"), self.onChangeModel)
-        self.connect(self.dialog.actionSuspend, SIGNAL("triggered()"), self.onSuspend)
-        self.connect(self.dialog.actionUnsuspend, SIGNAL("triggered()"), self.onUnsuspend)
+        self.connect(self.dialog.actionToggleSuspend, SIGNAL("triggered(bool)"), self.onSuspend)
+        self.connect(self.dialog.actionToggleMark, SIGNAL("triggered(bool)"), self.onMark)
         # edit
         self.connect(self.dialog.actionFont, SIGNAL("triggered()"), self.onFont)
         self.connect(self.dialog.actionUndo, SIGNAL("triggered()"), self.onUndo)
@@ -663,6 +689,7 @@ class EditDeck(QMainWindow):
         self.editor.setFact(None)
         self.editor.close()
         saveGeom(self, "editor")
+        saveState(self, "editor")
         saveHeader(self.dialog.tableView.horizontalHeader(), "editor")
         self.hide()
         ui.dialogs.close("CardList")
@@ -727,6 +754,7 @@ class EditDeck(QMainWindow):
         self.editor.setFact(fact, True)
         self.showCardInfo(self.currentCard)
         self.onEvent()
+        self.updateToggles()
 
     def setupCardInfo(self):
         self.currentCard = None
@@ -781,29 +809,46 @@ where id in (%s)""" % ",".join([
         self.updateSearch()
         self.updateAfterCardChange()
 
-    def addTags(self):
-        (tags, r) = ui.utils.getTag(self, self.deck, _("Enter tags to add:"))
+    def addTags(self, tags=None, label=None):
+        if tags is None:
+            (tags, r) = ui.utils.getTag(self, self.deck, _("Enter tags to add:"))
+        if label is None:
+            label = _("Add Tags")
         if tags:
-            n = _("Add Tags")
             self.parent.setProgressParent(self)
-            self.deck.setUndoStart(n)
+            self.deck.setUndoStart(label)
             self.deck.addTags(self.selectedFacts(), tags)
-            self.deck.setUndoEnd(n)
+            self.deck.setUndoEnd(label)
             self.parent.setProgressParent(None)
         self.updateAfterCardChange(reset=True)
 
-    def deleteTags(self):
-        (tags, r) = ui.utils.getTag(self, self.deck, _("Enter tags to delete:"))
+    def deleteTags(self, tags=None, label=None):
+        if tags is None:
+            (tags, r) = ui.utils.getTag(self, self.deck, _("Enter tags to delete:"))
+        if label is None:
+            label = _("Delete Tags")
         if tags:
-            n = _("Delete Tags")
             self.parent.setProgressParent(self)
-            self.deck.setUndoStart(n)
+            self.deck.setUndoStart(label)
             self.deck.deleteTags(self.selectedFacts(), tags)
-            self.deck.setUndoEnd(n)
+            self.deck.setUndoEnd(label)
             self.parent.setProgressParent(None)
         self.updateAfterCardChange(reset=True)
 
-    def onSuspend(self):
+    def updateToggles(self):
+        self.dialog.actionToggleSuspend.setChecked(self.isSuspended())
+        self.dialog.actionToggleMark.setChecked(self.isMarked())
+
+    def isSuspended(self):
+        return self.currentCard and self.currentCard.priority == -3
+
+    def onSuspend(self, sus):
+        if sus:
+            self._onSuspend()
+        else:
+            self._onUnsuspend()
+
+    def _onSuspend(self):
         n = _("Suspend")
         self.parent.setProgressParent(self)
         self.deck.setUndoStart(n)
@@ -812,7 +857,7 @@ where id in (%s)""" % ",".join([
         self.parent.setProgressParent(None)
         self.updateAfterCardChange(reset=True)
 
-    def onUnsuspend(self):
+    def _onUnsuspend(self):
         n = _("Unsuspend")
         self.parent.setProgressParent(self)
         self.deck.setUndoStart(n)
@@ -821,6 +866,21 @@ where id in (%s)""" % ",".join([
         self.parent.setProgressParent(None)
         self.updateAfterCardChange(reset=True)
 
+    def isMarked(self):
+        return self.currentCard and "Marked" in self.currentCard.fact.tags
+
+    def onMark(self, mark):
+        if mark:
+            self._onMark()
+        else:
+            self._onUnmark()
+
+    def _onMark(self):
+        self.addTags(tags="Marked", label=_("Toggle Mark"))
+
+    def _onUnmark(self):
+        self.deleteTags(tags="Marked", label=_("Toggle Mark"))
+
     def reschedule(self):
         n = _("Reschedule")
         d = QDialog(self)
@@ -921,13 +981,18 @@ where id in %s""" % ids2str(sf))
     ######################################################################
 
     def selectFacts(self):
+        self.deck.startProgress()
         sm = self.dialog.tableView.selectionModel()
+        sm.blockSignals(True)
         cardIds = dict([(x, 1) for x in self.selectedFactsAsCards()])
         for i, card in enumerate(self.model.cards):
             if card.id in cardIds:
                 sm.select(self.model.index(i, 0),
                           QItemSelectionModel.Select | QItemSelectionModel.Rows)
-
+            if i % 100 == 0:
+                self.deck.updateProgress()
+        sm.blockSignals(False)
+        self.deck.finishProgress()
 
     def invertSelection(self):
         sm = self.dialog.tableView.selectionModel()
@@ -1283,6 +1348,11 @@ class ChangeModelDialog(QDialog):
         # check maps
         fmap = self.getFieldMap()
         cmap = self.getTemplateMap()
+        def any(l):
+            for x in l:
+                if x:
+                    return True
+            return False
         if not cmap or (self.targetModel != self.oldModel and
                         not fmap):
             return ui.utils.showInfo(
